@@ -2,9 +2,10 @@ from os.path import exists
 from os import makedirs
 from os import remove
 from os.path import basename
-from random import choice
+import random
 import string
 import json
+from datetime import datetime
 # util functions (self explanatory)
 
 
@@ -23,6 +24,44 @@ def get_key_from_value(actual_dict, val):
             return key
     raise ValueError(f"key for {val} not found")
 
+def return_seed_value(seed_and_clen : str):
+    specific_clen = 1
+    try:
+        seed , specific_clen = [int (section) for section in seed_and_clen.split("@")]
+    except:
+        pass    
+    tmp_return_value = {}
+    tmp_return_value["chunk-length"] = specific_clen
+    tmp_return_value["keys"] = {}
+    ALPHABETS = string.ascii_letters + string.punctuation + string.digits
+    ALPHABETS_LIST = list(ALPHABETS)
+    random.seed(seed)
+    
+    rand_state = random.getstate()
+    
+    random.setstate(rand_state)
+    used_assignments_rand = []
+    for letter in ALPHABETS:
+        temp_rand_key = []
+        while True:
+            for __ in range(specific_clen):
+                temp_rand_key.append(random.choice(ALPHABETS_LIST))
+            rand_char = "".join(temp_rand_key)
+            
+            if specific_clen > 1 and rand_char not in used_assignments_rand:
+                used_assignments_rand.append(rand_char)            
+                break
+            elif specific_clen  == 1:
+                ALPHABETS_LIST.remove(rand_char)
+                break
+            
+            
+            
+
+        tmp_return_value["keys"][letter] = rand_char
+    return tmp_return_value
+    
+    
 
 class StrencCLI:
     
@@ -30,15 +69,11 @@ class StrencCLI:
     DEBUG = 'false'
     path_to_keys = None
     
-    # all commands and arguments
+    # commands and arguments that requires value
     SYSTEM_ARGS = [{
         'com': '-k',
         'val': '--key',
         'help': 'Get value of specific key'
-    }, {
-        'com': '-copy',
-        'val': '--copy',
-        'help': 'Get a copy of the keys'
     }, {
         'com':
         '-change',
@@ -54,10 +89,6 @@ class StrencCLI:
         'com': '-path',
         'val': '--keypath',
         'help': 'Loaction of keys.json'
-    }, {
-        'com': '-v',
-        'val': '--version',
-        'help': 'Outputs installed version of strenc'
     }, {
         'com':
         '-config',
@@ -101,6 +132,23 @@ class StrencCLI:
       '--value',
       'help':
       'Get key for a specific value'             
+    },{
+      'com':
+      '-s',
+      'val':
+      '--seed',
+      'help':
+      'Use a specific seed instead of a key file. Format: [seed/chunklength]'             
+    }]
+    # query commands
+    QUERY_ARGS = [ {
+        'com': '-v',
+        'val': '--version',
+        'help': 'Outputs installed version of strenc',
+    },  {
+        'com': '-copy',
+        'val': '--copy',
+        'help': 'Get a copy of the keys'
     }]
     __author__ = 'Saptak De'
     
@@ -133,6 +181,10 @@ class StrencCLI:
             self.arg_parser.add_argument(command['com'],
                                      command['val'],
                                      help=command['help'])
+        for command_bool in self.QUERY_ARGS:
+            self.arg_parser.add_argument(command_bool['com'],
+                                     command_bool['val'],
+                                     help=command_bool['help'] , action = 'store_true')    
 
         self.args = self.arg_parser.parse_args()  # initialize args fetcher
         
@@ -142,13 +194,15 @@ class StrencCLI:
     # initializing the logger
     
     def init_logger(self):
+        now = datetime.now()
         if self.DEBUG == 'true':
-            self.logger.basicConfig(filename='strenc.log',
+            if not exists("./log/"):
+                makedirs("./log/")
+            self.logger.basicConfig(filename=f'log/strenc_{now.strftime("%H-%M-%S")}.log',
                                            filemode='w',
                                            format='%(asctime)s - %(message)s',
                                            level=self.logger.NOTSET)
-        elif exists('strenc.log') and self.DEBUG == 'false':
-            remove('strenc.log')
+        
         
     # initialize configuration system
     
@@ -176,6 +230,8 @@ class StrencCLI:
     type_with_genkeys = False
     folds_with_file = False
     clen_with_keygen = False
+    seed_with_file = False
+    
     
     # initialize key related variables
     
@@ -304,7 +360,7 @@ class StrencCLI:
     # get a copy of keys.json file
     
     def get_copy(self , arg_copy):
-        if arg_copy == 'true':    
+        if arg_copy:    
             try:
                 print(self.key_dict)
             except Exception as err:
@@ -312,9 +368,7 @@ class StrencCLI:
                 err,
                 '-copy did not work. Either -path is wrong or it is absent.'
                 )
-        else:
-            print("Add true after -copy")        
-
+        
     # generate keys.json file
     
     def gen_keys(self , genpath , gentype , arg_clen):
@@ -328,7 +382,7 @@ class StrencCLI:
                 self.err_logging(err , "Chunk length value must be a integer")
         else:
             try:
-                chunk_length = int(input("Please enter chunk length value (Default =1)"))
+                chunk_length = int(input("Please enter chunk length value (Default =1) : "))
             except Exception as err:
                 chunk_length = 1
                 self.err_logging(err , "Chunk length value is not a integer.Defaulting to 1")               
@@ -377,7 +431,7 @@ class StrencCLI:
                         temp_rand_key = []
                         while True:
                             for __ in range(chunk_length):
-                                temp_rand_key.append(choice(ALPHABETS_LIST))
+                                temp_rand_key.append(random.choice(ALPHABETS_LIST))
                             rand_char = "".join(temp_rand_key)
                             
                             if chunk_length > 1 and rand_char not in used_assignments_rand:
@@ -411,10 +465,9 @@ class StrencCLI:
     # show current strenc version
     
     def show_version(self , arg_show):
-        if arg_show == 'show':
+        if arg_show:
             print(f'strenc version {self.__version__}')
-        else:
-            print('Please add show after -v')
+        
 
     # setup or change config file
     
@@ -475,18 +528,21 @@ class StrencCLI:
 
     # run gatekeep
     
-    def gatekeep(self , gentype , arg_folds):
+    def gatekeep(self , gentype , arg_folds , arg_seed):
         if gentype and not self.type_with_genkeys:
             print('Run -type alongside -genpath')
         if arg_folds and not self.folds_with_file:
             print('Use argument -folds with either -encfile or -decfile')
+        if arg_seed and not self.seed_with_file:
+            print('Use argument -s or --seed with either -encfile or -decfile')    
            
 
     # .txt file encoding
     
-    def encode_file(self , encfile , arg_folds):
+    def encode_file(self , encfile , arg_folds , arg_seed):
         
         self.folds_with_file = True
+        self.seed_with_file = True
         folds = 1
         #get value of 'folds' if given
         if arg_folds:
@@ -495,7 +551,13 @@ class StrencCLI:
             except Exception as err:
                 self.err_logging(
                     err, 'value of argument -folds should be a integer')
-
+        # use seed if given , else use the given key file
+        
+        if arg_seed:
+            try:
+                self.key_dict  = return_seed_value(arg_seed)
+            except Exception as err:
+                self.err_logging(err , "Value of -s or --seed should be a integer")    
         if exists(encfile):
             file_to_encode = open(encfile, "r")
             # gets all the line of the file
@@ -541,9 +603,10 @@ class StrencCLI:
 
     # decode a encoded file
     
-    def decode_file(self , decfile_arg , arg_folds):
+    def decode_file(self , decfile_arg , arg_folds , arg_seed):
         if decfile_arg:
             self.folds_with_file = True
+            self.seed_with_file = True
             folds = 1
             #get value of 'folds' if given
             if arg_folds:
@@ -551,6 +614,12 @@ class StrencCLI:
                     folds = int(arg_folds)
                 except Exception as err:
                     self.err_logging(err , 'value of argument -folds should be a integer')
+            if arg_seed:
+                try:
+                    self.key_dict = return_seed_value(arg_seed)
+                    self.clen = self.key_dict["chunk-length"]
+                except Exception as err:
+                    self.err_logging(err , "Value of -s or --seed should be a integer")            
             if exists(decfile_arg):
                 file_to_decode = open(decfile_arg, "r")
                 content_of_file_dec = file_to_decode.readlines()
